StructType

Struct StructType 

pub struct StructType { /* private fields */ }
Represents a c-like struct type. Limitations and warnings on its usage are similar to that in MLIR. <https://mlir.llvm.org/docs/Dialects/LLVM/#structure-types>

  1. Anonymous (aka unnamed) structs cannot be recursive.
  2. Named structs are uniqued only by name, and may be recursive.
  3. LLVM calls anonymous structs as literal structs and named structs as identified structs.
  4. Named structs may be opaque, i.e., no body specificed. Recursive types may be created by first creating an opaque struct and later setting its body.

Implementations

Source

impl StructType

pub fn get_named( ctx: &Context, name: Identifier, body: Option<(Vec<TypeHandle>, StructLayout)>, ) -> Result<TypedHandle<Self>>

Get or create a named StructType. If body is None, it indicates an opaque struct. A body can be added to opaque structs by calling this again later. Returns an error if all of the below conditions are true: a. The name is already registered b. The body is already set (i.e, the struct is not oqaue) c. The body provided here don’t match with the existing body. Since named structs only rely on the name for uniqueness, It is not an error to provide body as None even when the named struct already exists and has its body set.

pub fn get_unnamed( ctx: &Context, body: (Vec<TypeHandle>, StructLayout), ) -> TypedHandle<Self>

Get or create a new unnamed (anonymous) struct. These are finalized upon creation, and uniqued based on the fields and layout.

pub fn is_opaque(&self) -> bool

A struct without a body set is opaque

pub fn is_named(&self) -> bool

Is this a named struct?

pub fn name(&self) -> Option<Identifier>

Get this struct’s name, if it has one.

pub fn layout(&self) -> StructLayout

Get this struct’s layout.

Panics if the struct is opaque.

pub fn field_type(&self, field_idx: usize) -> TypeHandle

Get type of the idx’th field.

Panics if the struct is opaque or the index is invalid.

pub fn num_fields(&self) -> usize

Get the number of fields this struct has

Panics if the struct is opaque.

pub fn fields(&self) -> impl Iterator<Item = TypeHandle> + '_

Get an iterator over the fields of this struct.

Panics if the struct is opaque.