pub struct StructType { /* private fields */ }Expand description
Represents a c-like struct type.
Limitations and warnings on its usage are similar to that in MLIR.
<https://mlir.llvm.org/docs/Dialects/LLVM/#structure-types>
- Anonymous (aka unnamed) structs cannot be recursive.
- Named structs are uniqued only by name, and may be recursive.
- LLVM calls anonymous structs as literal structs and named structs as identified structs.
- Named structs may be opaque, i.e., no body specificed. Recursive types may be created by first creating an opaque struct and later setting its body.
Implementations
Sourceimpl StructType
impl StructType
Sourcepub fn get_named(
ctx: &Context,
name: Identifier,
body: Option<(Vec<TypeHandle>, StructLayout)>,
) -> Result<TypedHandle<Self>>
pub fn get_named( ctx: &Context, name: Identifier, body: Option<(Vec<TypeHandle>, StructLayout)>, ) -> Result<TypedHandle<Self>>
Get or create a named StructType.
If body is None, it indicates an opaque struct.
A body can be added to opaque structs by calling this again later.
Returns an error if all of the below conditions are true:
a. The name is already registered
b. The body is already set (i.e, the struct is not oqaue)
c. The body provided here don’t match with the existing body.
Since named structs only rely on the name for uniqueness,
It is not an error to provide body as None even when
the named struct already exists and has its body set.
Sourcepub fn get_unnamed(
ctx: &Context,
body: (Vec<TypeHandle>, StructLayout),
) -> TypedHandle<Self>
pub fn get_unnamed( ctx: &Context, body: (Vec<TypeHandle>, StructLayout), ) -> TypedHandle<Self>
Get or create a new unnamed (anonymous) struct. These are finalized upon creation, and uniqued based on the fields and layout.
Sourcepub fn layout(&self) -> StructLayout
pub fn layout(&self) -> StructLayout
Get this struct’s layout.
Panics if the struct is opaque.
Sourcepub fn field_type(&self, field_idx: usize) -> TypeHandle
pub fn field_type(&self, field_idx: usize) -> TypeHandle
Get type of the idx’th field.
Panics if the struct is opaque or the index is invalid.
Sourcepub fn num_fields(&self) -> usize
pub fn num_fields(&self) -> usize
Get the number of fields this struct has
Panics if the struct is opaque.