pub struct StructType { /* private fields */ }Expand description
Represents a c-like struct type.
Limitations and warnings on its usage are similar to that in MLIR.
<https://mlir.llvm.org/docs/Dialects/LLVM/#structure-types>
- Anonymous (aka unnamed) structs cannot be recursive.
- Named structs are uniqued only by name, and may be recursive.
- LLVM calls anonymous structs as literal structs and named structs as identified structs.
- Named structs may be opaque, i.e., no body specificed. Recursive types may be created by first creating an opaque struct and later setting its fields (body).
Implementations
Sourceimpl StructType
impl StructType
Sourcepub fn get_named(
ctx: &Context,
name: Identifier,
fields: Option<Vec<TypeHandle>>,
) -> Result<TypedHandle<Self>>
pub fn get_named( ctx: &Context, name: Identifier, fields: Option<Vec<TypeHandle>>, ) -> Result<TypedHandle<Self>>
Get or create a named StructType.
If fields is None, it indicates an opaque struct.
A body can be added to opaque structs by calling this again later.
Returns an error if all of the below conditions are true:
a. The name is already registered
b. The body is already set (i.e, the struct is not oqaue)
c. The fields provided here don’t match with the existing body.
Since named structs only rely on the name for uniqueness,
It is not an error to provide fields as None even when
the named struct already exists and has its body set.
Sourcepub fn get_unnamed(ctx: &Context, fields: Vec<TypeHandle>) -> TypedHandle<Self>
pub fn get_unnamed(ctx: &Context, fields: Vec<TypeHandle>) -> TypedHandle<Self>
Get or create a new unnamed (anonymous) struct. These are finalized upon creation, and uniqued based on the fields.
Sourcepub fn name(&self) -> Option<Identifier>
pub fn name(&self) -> Option<Identifier>
Get this struct’s name, if it has one.
Sourcepub fn field_type(&self, field_idx: usize) -> TypeHandle
pub fn field_type(&self, field_idx: usize) -> TypeHandle
Get type of the idx’th field.
Sourcepub fn num_fields(&self) -> usize
pub fn num_fields(&self) -> usize
Get the number of fields this struct has
Sourcepub fn fields(&self) -> impl Iterator<Item = TypeHandle> + '_
pub fn fields(&self) -> impl Iterator<Item = TypeHandle> + '_
Get an iterator over the fields of this struct