StructType

Struct StructType 

pub struct StructType { /* private fields */ }
Represents a c-like struct type. Limitations and warnings on its usage are similar to that in MLIR. <https://mlir.llvm.org/docs/Dialects/LLVM/#structure-types>

  1. Anonymous (aka unnamed) structs cannot be recursive.
  2. Named structs are uniqued only by name, and may be recursive.
  3. LLVM calls anonymous structs as literal structs and named structs as identified structs.
  4. Named structs may be opaque, i.e., no body specificed. Recursive types may be created by first creating an opaque struct and later setting its fields (body).

Implementations

Source

impl StructType

pub fn get_named( ctx: &mut Context, name: Identifier, fields: Option<Vec<Ptr<TypeObj>>>, ) -> Result<TypePtr<Self>>

Get or create a named StructType. If fields is None, it indicates an opaque struct. A body can be added to opaque structs by calling this again later. Returns an error if all of the below conditions are true: a. The name is already registered b. The body is already set (i.e, the struct is not oqaue) c. The fields provided here don’t match with the existing body. Since named structs only rely on the name for uniqueness, It is not an error to provide fields as None even when the named struct already exists and has its body set.

pub fn get_unnamed( ctx: &mut Context, fields: Vec<Ptr<TypeObj>>, ) -> TypePtr<Self>

Get or create a new unnamed (anonymous) struct. These are finalized upon creation, and uniqued based on the fields.

pub fn get_existing_named( ctx: &Context, name: &Identifier, ) -> Option<TypePtr<Self>>

If a named struct already exists, get a pointer to it.

pub fn get_existing_unnamed( ctx: &Context, fields: Vec<Ptr<TypeObj>>, ) -> Option<TypePtr<Self>>

If an unnamed struct already exists, get a pointer to it.

pub fn is_opaque(&self) -> bool

Does this struct not have its body set?

pub fn is_named(&self) -> bool

Is this a named struct?

pub fn name(&self) -> Option<Identifier>

Get this struct’s name, if it has one.

pub fn field_type(&self, field_idx: usize) -> Ptr<TypeObj>

Get type of the idx’th field.

pub fn num_fields(&self) -> usize

Get the number of fields this struct has

pub fn fields(&self) -> impl Iterator<Item = Ptr<TypeObj>> + '_

Get an iterator over the fields of this struct